.. hyperlinks.

.. _pymediainfo: https://pypi.org/project/pymediainfo/
.. _Python: https://www.python.org/downloads/
.. _MKVToolNix: https://mkvtoolnix.download/
.. _Matroska: https://www.matroska.org/
.. _MediaInfo: https://mediaarea.net/en/MediaInfo
.. _AVI: https://docs.microsoft.com/en-us/windows/desktop/directshow/avi-file-format/
.. _SRT: https://matroska.org/technical/specs/subtitles/srt.html
.. _MKVBatchMultiplex: https://github.com/akai10tsuki/mkvbatchmultiplex
.. _`The TV Database`: https://www.thetvdb.com/
.. _`The Movie Database`: https://www.themoviedb.org/
.. _`ubuntu 18.04 LTS`: https://www.ubuntu.com/
.. _`macOS 10.14 Mojave`: https://www.apple.com/macos/mojave/
.. _`Windows 10`: https://www.microsoft.com/en-us/windows
.. _lxml: https://lxml.de/
